1.2
===

Added test suite and automated deployments for tagged
commits.

1.1
===

Move hosting to github.

1.0
===

Initial implementation with text and HTML support on Windows
and Mac OS X and image paste support on Windows.
